@@ -1,5 +1,5 @@
-from ..overrides import override
-from ..importer import modules
+from gi.overrides import override
+from gi.importer import modules
 
 Dee = modules['Dee']._introspection_module
 from gi.repository import GLib
@@ -63,6 +63,12 @@ class Model(Dee.Model):
     def insert_before (self, iter, *args):
         return self.insert_row_before (iter, self._build_row(args))
     
+    def insert_sorted (self, sort_func, *args):
+    	return self.insert_row_sorted (self._build_row(args), sort_func, None)
+   
+    def find_sorted (self, sort_func, *args):
+    	return self.find_row_sorted (self._build_row(args), sort_func, None)
+    
     def get_schema (self):
         return Dee.Model.get_schema(self)[0]
     
