@@ -22,9 +22,32 @@
 #include <time.h>
 #include <glib.h>
 #include <glib-object.h>
+#include <glib/gprintf.h>
 
 #include <dee.h>
 
+static void
+on_swarm_leader_changed (GObject *peer_o, GParamSpec *pspec, gpointer user_data)
+{
+  gchar *swarm_leader;
+
+  g_object_get (peer_o, "swarm-leader", &swarm_leader, NULL);
+  g_printf ("Swarm leader changed: %s\n", swarm_leader);
+  g_free (swarm_leader);
+}
+
+static void
+on_peer_found (DeePeer *self, const gchar* peer_name)
+{
+  g_printf ("Peer found: %s\n", peer_name);
+}
+
+static void
+on_peer_lost (DeePeer *self, const gchar* peer_name)
+{
+  g_printf ("Peer lost: %s\n", peer_name);
+}
+
 gint
 main (gint argc, gchar *argv[])
 {
@@ -37,8 +60,11 @@ main (gint argc, gchar *argv[])
   peer = g_object_new (DEE_TYPE_PEER,
                        "swarm-name", "com.canonical.DeePeer.Test",
                        NULL);
-  dee_peer_connect (peer);
   
+  g_signal_connect (peer, "notify::swarm-leader", G_CALLBACK (on_swarm_leader_changed), NULL);
+  g_signal_connect (peer, "peer-found", G_CALLBACK (on_peer_found), NULL);
+  g_signal_connect (peer, "peer-lost", G_CALLBACK (on_peer_lost), NULL);
+
   loop = g_main_loop_new (NULL, FALSE);
   g_main_loop_run (loop);
 
