@@ -25,6 +25,23 @@
 #include <gtx.h>
 #include <dee.h>
 
+guint64 before_begin_seqnum, before_end_seqnum,
+        after_begin_seqnum, after_end_seqnum;
+
+static void
+_begin_txn (DeeSharedModel *model, guint64 begin_seqnum, guint64 end_seqnum)
+{
+  before_begin_seqnum = begin_seqnum;
+  before_end_seqnum = end_seqnum;
+}
+
+static void
+_end_txn (DeeSharedModel *model, guint64 begin_seqnum, guint64 end_seqnum)
+{
+  after_begin_seqnum = begin_seqnum;
+  after_end_seqnum = end_seqnum;
+}
+
 static void
 _row_added (DeeModel *model, DeeModelIter *iter, GSList **rows_so_far)
 {
@@ -43,7 +60,13 @@ main (gint argc, gchar *argv[])
   g_type_init (); 
   g_thread_init (NULL);
 
-  model = dee_shared_model_new (argv[1]);
+  if (argc == 2)
+    model = dee_shared_model_new (argv[1]);
+  else
+    model = dee_shared_model_new_for_peer ((DeePeer*) dee_client_new (argv[1]));
+
+  g_signal_connect (model, "begin-transaction", G_CALLBACK (_begin_txn), NULL);
+  g_signal_connect (model, "end-transaction", G_CALLBACK (_end_txn), NULL);
 
   /* Wait until we find the leader */
   if (gtx_wait_for_signal (G_OBJECT (model), 1000, "notify::synchronized", NULL))
@@ -77,5 +100,13 @@ main (gint argc, gchar *argv[])
   g_assert_cmpint (dee_model_get_int32 (model, iter, 0), == , 2);
   g_assert_cmpstr (dee_model_get_string (model, iter, 1), == , "two");
   
+  gtx_assert_last_unref (model);
+  g_slist_free (rows_added);
+  
+  g_assert (before_begin_seqnum == after_begin_seqnum);
+  g_assert (before_end_seqnum == after_end_seqnum);
+  g_assert_cmpint (0, ==, (guint) before_begin_seqnum);
+  g_assert_cmpint (3, ==, (guint) before_end_seqnum);
+  
   return 0;
 }
