@@ -42,7 +42,11 @@ main (gint argc, gchar *argv[])
   
   g_type_init (); 
 
-  model = dee_shared_model_new (argv[1]);
+  if (argc == 2)
+    model = dee_shared_model_new (argv[1]);
+  else
+    model = dee_shared_model_new_for_peer ((DeePeer*) dee_client_new (argv[1]));
+
   
   if (gtx_wait_for_signal (G_OBJECT (model), 1000, "notify::synchronized", NULL))
     g_error ("Helper model timed out waiting for 'ready' signal");
@@ -75,5 +79,8 @@ main (gint argc, gchar *argv[])
   g_assert_cmpint (dee_model_get_int32 (model, iter, 0), == , 2);
   g_assert_cmpstr (dee_model_get_string (model, iter, 1), == , "changed_two");
   
+  gtx_assert_last_unref (model);
+  g_slist_free (changes);
+  
   return 0;
 }
