@@ -25,6 +25,23 @@
 #include <gtx.h>
 #include <dee.h>
 
+guint64 before_begin_seqnum, before_end_seqnum,
+        after_begin_seqnum, after_end_seqnum;
+
+static void
+_begin_txn (DeeSharedModel *model, guint64 begin_seqnum, guint64 end_seqnum)
+{
+  before_begin_seqnum = begin_seqnum;
+  before_end_seqnum = end_seqnum;
+}
+
+static void
+_end_txn (DeeSharedModel *model, guint64 begin_seqnum, guint64 end_seqnum)
+{
+  after_begin_seqnum = begin_seqnum;
+  after_end_seqnum = end_seqnum;
+}
+
 static void
 _row_removed (DeeModel *model, DeeModelIter *iter, GSList **removed)
 {
@@ -42,7 +59,13 @@ main (gint argc, gchar *argv[])
   g_type_init (); 
   g_thread_init (NULL);
 
-  model = dee_shared_model_new (argv[1]);
+  if (argc == 2)
+    model = dee_shared_model_new (argv[1]);
+  else
+    model = dee_shared_model_new_for_peer ((DeePeer*) dee_client_new (argv[1]));
+
+  g_signal_connect (model, "begin-transaction", G_CALLBACK (_begin_txn), NULL);
+  g_signal_connect (model, "end-transaction", G_CALLBACK (_end_txn), NULL);
   
   if (gtx_wait_for_signal (G_OBJECT (model), 100000, "notify::synchronized", NULL))
     g_error ("Helper model timed out waiting for 'ready' signal");
@@ -59,5 +82,15 @@ main (gint argc, gchar *argv[])
   g_assert_cmpint (g_slist_length (removed), ==, 3);
   g_assert_cmpint (dee_model_get_n_rows(model), ==, 0);
   
+  g_assert_cmpint (6, ==, (guint) dee_serializable_model_get_seqnum (model));
+  
+  g_assert (before_begin_seqnum == after_begin_seqnum);
+  g_assert (before_end_seqnum == after_end_seqnum);
+  g_assert_cmpint (3, ==, (guint) before_begin_seqnum);
+  g_assert_cmpint (6, ==, (guint) before_end_seqnum);
+  
+  gtx_assert_last_unref (model);
+  g_slist_free (removed);
+  
   return 0;
 }
