@@ -25,18 +25,34 @@
 #include <gtx.h>
 #include <dee.h>
 
+static void
+row_added (DeeModel *model, DeeModelIter *iter, gpointer data)
+{
+  gint *num_added = (gint*) data;
+  (*num_added)++;
+}
+
 /* Expects a clone with 3 rows in it */
 gint
 main (gint argc, gchar *argv[])
 {
   DeeModel     *model;
   DeeModelIter *iter;
+  gint          num_added;
   
   g_type_init (); 
   g_thread_init (NULL);
 
-  model = dee_shared_model_new (argv[1]);
-  
+  g_set_prgname ("model-helper");
+
+  if (argc == 2)
+    model = dee_shared_model_new (argv[1]);
+  else
+    model = dee_shared_model_new_for_peer ((DeePeer*) dee_client_new (argv[1]));
+
+  num_added = 0;
+  g_signal_connect (model, "row-added", G_CALLBACK (row_added), &num_added);
+
   if (gtx_wait_for_signal (G_OBJECT (model), 100000, "notify::synchronized", NULL))
     g_error ("Helper model timed out waiting for 'ready' signal");
 
@@ -54,5 +70,8 @@ main (gint argc, gchar *argv[])
   g_assert_cmpint (dee_model_get_int32 (model, iter, 0), == , 2);
   g_assert_cmpstr (dee_model_get_string (model, iter, 1), == , "two");
   
+  gtx_assert_last_unref (model);
+  g_assert_cmpint (num_added, ==, 3);
+  
   return 0;
 }
