@@ -43,7 +43,11 @@ main (gint argc, gchar *argv[])
   g_type_init (); 
   g_thread_init (NULL);
 
-  model = dee_shared_model_new (argv[1]);
+  if (argc == 2)
+    model = dee_shared_model_new (argv[1]);
+  else
+    model = dee_shared_model_new_for_peer ((DeePeer*) dee_client_new (argv[1]));
+
 
   /* Wait until we find the leader */
   if (gtx_wait_for_signal (G_OBJECT (model), 1000, "notify::synchronized", NULL))
@@ -66,6 +70,9 @@ main (gint argc, gchar *argv[])
   g_assert_cmpint (dee_model_get_position (model, iter), == , 1);
   g_assert_cmpint (dee_model_get_int32 (model, iter, 0), == , 27);
   g_assert_cmpstr (dee_model_get_string (model, iter, 1), == , "twentyseven");
- 
+  
+  gtx_assert_last_unref (model);
+  g_slist_free (rows_added);
+  
   return 0;
 }
