@@ -53,7 +53,11 @@ main (gint argc, gchar *argv[])
   
   g_type_init (); 
 
-  model = dee_shared_model_new (argv[1]);
+  if (argc == 2)
+    model = dee_shared_model_new (argv[1]);
+  else
+    model = dee_shared_model_new_for_peer ((DeePeer*) dee_client_new (argv[1]));
+
 
   if (gtx_wait_for_signal (G_OBJECT (model), 1000, "notify::synchronized", NULL))
     g_error ("Helper model timed out waiting for 'ready' signal");
@@ -97,5 +101,8 @@ main (gint argc, gchar *argv[])
       g_error ("Expected original row 3 on position 1. Found row with data '%s'",
                dee_model_get_string (model, iter, 1));
   
+  gtx_assert_last_unref (model);
+  g_slist_free (changes);
+  
   return 0;
 }
