@@ -20,6 +20,7 @@
 #include "config.h"
 #include <glib.h>
 #include <glib-object.h>
+#include <locale.h>
 
 void test_model_column_create_suite (void);
 void test_model_complex_column_create_suite (void);
@@ -30,16 +31,23 @@ void test_model_tags_create_suite (void);
 void test_filter_model_create_suite (void);
 void test_term_list_create_suite (void);
 void test_hash_index_create_suite (void);
-void test_analyzers_create_suite (void);
+void test_analyzer_create_suite (void);
+void test_model_readers_create_suite (void);
 void test_glist_result_set_create_suite (void);
 void test_serializable_create_suite (void);
 void test_resource_manager_create_suite (void);
+void test_transaction_create_suite (void);
 
 #ifdef HAVE_GTX
 void test_model_interactions_create_suite(void);
 void test_peer_interactions_create_suite(void);
+void test_client_server_interactions_create_suite(void);
 #endif  /* HAVE_GTX */
 
+#ifdef HAVE_ICU
+void test_icu_create_suite(void);
+#endif  /* HAVE_ICU */
+
 gint
 main (gint argc, gchar *argv[])
 {
@@ -47,6 +55,7 @@ main (gint argc, gchar *argv[])
   g_thread_init (NULL);
 
   g_test_init (&argc, &argv, NULL);
+  setlocale (LC_ALL, "");
 
   test_model_column_create_suite ();
   test_model_complex_column_create_suite ();
@@ -57,17 +66,24 @@ main (gint argc, gchar *argv[])
   test_filter_model_create_suite ();
   test_term_list_create_suite ();
   test_hash_index_create_suite ();
-  test_analyzers_create_suite ();
+  test_analyzer_create_suite ();
+  test_model_readers_create_suite ();
   test_glist_result_set_create_suite ();
   test_serializable_create_suite ();
   test_resource_manager_create_suite ();
+  test_transaction_create_suite ();
 
 #ifdef HAVE_GTX
   test_model_interactions_create_suite();
   test_peer_interactions_create_suite();
+  test_client_server_interactions_create_suite();
 #else
   g_message ("Interactions' test suite disabled. GTX not found. You can download GTX from https://launchpad.net/gtx");
 #endif  /* HAVE_GTX */
   
+#ifdef HAVE_ICU
+  test_icu_create_suite ();
+#endif
+
   return g_test_run ();
 }
