@@ -120,16 +120,18 @@ append_all_model_map (DeeModel       *orig_model,
     }
 }
 
-static void
+static gboolean
 discard_all_model_notify (DeeModel       *orig_model,
                           DeeModelIter   *orig_iter,
                           DeeFilterModel *mapped_model,
                           gpointer        user_data)
 {
   /* Do nothing */
+
+  return FALSE;
 }
 
-static void
+static gboolean
 append_all_model_notify (DeeModel       *orig_model,
                          DeeModelIter   *orig_iter,
                          DeeFilterModel *mapped_model,
@@ -138,6 +140,8 @@ append_all_model_notify (DeeModel       *orig_model,
   /* Always say "Thank you, I am delighted",
    * and append the new row to @mapped_model */
   dee_filter_model_append_iter (mapped_model, orig_iter);
+
+  return TRUE;
 }
 
 static void
@@ -150,15 +154,18 @@ signal_counter (DeeModel *model, DeeModelIter *iter, guint *count)
 static void
 test_empty_orig (FilterFixture *fix, gconstpointer data)
 {
-  DeeFilter *filter = g_new0 (DeeFilter, 1);
-  filter->map_func = append_all_model_map;
-  filter->map_notify = append_all_model_notify;
-  filter->user_data = fix;
+  DeeFilter filter;
+
+  dee_filter_new (append_all_model_map,
+                  append_all_model_notify,
+                  fix,
+                  NULL,
+                  &filter);
   
   dee_model_clear (fix->model);
   g_assert_cmpint (0, ==, dee_model_get_n_rows (fix->model));
   
-  DeeModel *m = dee_filter_model_new (filter, fix->model);
+  DeeModel *m = dee_filter_model_new (fix->model, &filter);
   g_assert_cmpint (0, ==, dee_model_get_n_rows (fix->model));
   
   DeeModelIter *iter = dee_model_get_first_iter (m);
@@ -170,12 +177,15 @@ test_empty_orig (FilterFixture *fix, gconstpointer data)
 static void
 test_append_all (FilterFixture *fix, gconstpointer data)
 {
-  DeeFilter filter = { 0 };
-  filter.map_func = append_all_model_map;
-  filter.map_notify = append_all_model_notify;
-  filter.user_data = fix;
+  DeeFilter filter;
+
+  dee_filter_new (append_all_model_map,
+                  append_all_model_notify,
+                  fix,
+                  NULL,
+                  &filter);
   
-  DeeModel *m = dee_filter_model_new (&filter, fix->model);
+  DeeModel *m = dee_filter_model_new (fix->model, &filter);
   g_assert_cmpint (3, ==, dee_model_get_n_rows (fix->model));
   
   DeeModelIter *iter = dee_model_get_first_iter (m);
@@ -207,12 +217,15 @@ test_append_all (FilterFixture *fix, gconstpointer data)
 static void
 test_discard_all (FilterFixture *fix, gconstpointer data)
 {
-  DeeFilter filter = { 0 };
-  filter.map_func = discard_all_model_map;
-  filter.map_notify = discard_all_model_notify;
-  filter.user_data = fix;
+  DeeFilter filter;
+
+  dee_filter_new (discard_all_model_map,
+                  discard_all_model_notify,
+                  fix,
+                  NULL,
+                  &filter);
   
-  DeeModel *m = dee_filter_model_new (&filter, fix->model);
+  DeeModel *m = dee_filter_model_new (fix->model, &filter);
   
   /* Check expected sizes */
   g_return_if_fail (DEE_IS_FILTER_MODEL (m));
@@ -261,12 +274,15 @@ test_discard_all (FilterFixture *fix, gconstpointer data)
 static void
 test_discard_all_append_notify (FilterFixture *fix, gconstpointer data)
 {
-  DeeFilter filter = { 0 };
-  filter.map_func = discard_all_model_map;
-  filter.map_notify = append_all_model_notify;
-  filter.user_data = fix;
+  DeeFilter filter;
   
-  DeeModel *m = dee_filter_model_new (&filter, fix->model);
+  dee_filter_new (discard_all_model_map,
+                  append_all_model_notify,
+                  fix,
+                  NULL,
+                  &filter);
+
+  DeeModel *m = dee_filter_model_new (fix->model, &filter);
   
   guint filter_add_count = 0;
   guint orig_add_count = 0;
@@ -310,10 +326,11 @@ static void
 test_collator_asc (FilterFixture *fix, gconstpointer data)
 {
   DeeModelIter *r0, *r1, *r2, *r3, *r4, *r5;
-  DeeFilter    *collator = dee_filter_new_collator (1);
-  DeeModel     *m = dee_filter_model_new (collator, fix->model);
+  DeeFilter    collator;
+  DeeModel     *m;
 
-  g_free (collator);
+  dee_filter_new_collator (1, &collator);
+  m  = dee_filter_model_new (fix->model, &collator);
 
   /* Test alphabetic sorting after initial construction */
   r0 = dee_model_get_iter_at_row (m, 0);
@@ -353,10 +370,11 @@ static void
 test_collator_desc (FilterFixture *fix, gconstpointer data)
 {
   DeeModelIter *r0, *r1, *r2, *r3, *r4, *r5;
-  DeeFilter    *collator = dee_filter_new_collator_desc (1);
-  DeeModel     *m = dee_filter_model_new (collator, fix->model);
+  DeeFilter    collator;
+  DeeModel     *m;
 
-  g_free (collator);
+  dee_filter_new_collator_desc (1, &collator);
+  m  = dee_filter_model_new (fix->model, &collator);
 
   /* Test alphabetic sorting after initial construction */
   r0 = dee_model_get_iter_at_row (m, 0);
@@ -396,7 +414,7 @@ _test_orig_ordering (FilterFixture *fix,
                      DeeFilter     *filter)
 {
   DeeModelIter *r0, *r1, *r2, *r3, *r4;//, *r5;
-  DeeModel     *m = dee_filter_model_new (filter, fix->model);
+  DeeModel     *m = dee_filter_model_new (fix->model, filter);
 
   /* Assert that the initial filtering is good:
    * { [  0, "Zero" ] }        { [  0, "Zero" ],
@@ -492,34 +510,33 @@ _test_orig_ordering (FilterFixture *fix,
 static void
 test_key (FilterFixture *fix, gconstpointer data)
 {
-  DeeFilter    *filter = dee_filter_new_for_key_column (1, "Zero");
+  DeeFilter    filter;
 
-  _test_orig_ordering (fix, filter);
-  g_free (filter);
+  dee_filter_new_for_key_column (1, "Zero", &filter);
+  _test_orig_ordering (fix, &filter);
 }
 
 /* Test dee_filter_new_for_any_column() */
 static void
 test_any (FilterFixture *fix, gconstpointer data)
 {
-  DeeFilter    *filter =
-            dee_filter_new_for_any_column (1, g_variant_new_string ("Zero"));
+  DeeFilter    filter;
 
-  _test_orig_ordering (fix, filter);
-  g_free (filter);
+  dee_filter_new_for_any_column (1, g_variant_new_string ("Zero"), &filter);
+
+  _test_orig_ordering (fix, &filter);
 }
 
 /* Test dee_filter_new_regex() */
 static void
 test_regex (FilterFixture *fix, gconstpointer data)
 {
-  DeeFilter    *filter;
+  DeeFilter    filter;
   GRegex       *regex;
 
   regex = g_regex_new (".ero", 0, 0, NULL);
-  filter = dee_filter_new_regex (1, regex);
+  dee_filter_new_regex (1, regex, &filter);
 
-  _test_orig_ordering (fix, filter);
+  _test_orig_ordering (fix, &filter);
   g_regex_unref (regex);
-  g_free (filter);
 }
